@@ -1,4 +1,5 @@
 from copy import copy
+from inspect import isclass
 import sqlalchemy as sa
 from .translatable import Translatable
 from .builders import (
@@ -70,6 +71,11 @@ class TranslationManager(object):
             return self.options[name]
 
     def build_relationships(self, model):
+        """
+        Build translation relationships for given SQLAlchemy declarative model.
+
+        :param model: SQLAlchemy declarative model
+        """
         translation_cls = model.__translatable__['class']
         for locale in self.option(model, 'locales'):
             setattr(
@@ -97,19 +103,45 @@ class TranslationManager(object):
             )
         )
 
+    def create_missing_locales(self, obj):
+        """
+        Creates empty locale objects for given SQLAlchemy declarative object.
+
+        :param model: SQLAlchemy declarative model object
+        """
+        session = sa.orm.session.object_session(obj)
+        for locale in self.option(obj, 'locales'):
+            if obj.translations[locale] is None:
+                class_ = obj.__translatable__['class']
+                obj.translations[locale] = class_(
+                    translation_parent=obj,
+                    locale=locale
+                )
+
+                for column in obj.__translated_columns__:
+                    if (
+                        not column.nullable and
+                        is_string(column.type) and
+                        column.default is None and
+                        column.server_default is None
+                    ):
+                        setattr(obj.translations[locale], column.name, u'')
+
+                session.add(obj)
+
     def auto_create_translations(self, session, flush_context, instances):
         if not self.options['auto_create_locales']:
             return
         for obj in session.new:
             if hasattr(obj, '__translatable__'):
-                for locale in self.option(obj, 'locales'):
-                    if obj.translations[locale] is None:
-                        class_ = obj.__translatable__['class']
-                        obj.translations[locale] = class_(
-                            translation_parent=obj,
-                            locale=locale
-                        )
-                        session.add(obj)
+                self.create_missing_locales(obj)
 
 
 translation_manager = TranslationManager()
+
+
+def is_string(type_):
+    return (
+        isinstance(type_, sa.String) or
+        (isclass(type_) and issubclass(type_, sa.String))
+    )
